@@ -4,7 +4,7 @@ use warnings;
 use base qw/Class::Component::Plugin/;
 use LWP::UserAgent;
 
-sub check : Hook('check') {
+sub check : Hook {
     my ($self, $context, $args) = @_;
 
     my $conf = $self->config->{config};
